==> bupstash-0.11.1.tar.gz: bupstash-0.11.1/doc/man/bupstash-authors.7.md <==
bupstash-authors(7)
===================

## SYNOPSIS

The bupstash authors, how to contact them, and their bupstash specific PGP public keys.

## Andrew Chambers

### About

Andrew is an an experienced programmer with a masters degree in computer systems engineering 
from the university of Auckland in New Zealand. He is the creator and primary author of bupstash
and bupstash.io.

### Contact

Email: ac@bupstash.io

### PGP Key

```
-----BEGIN PGP PUBLIC KEY BLOCK-----

mDMEYvRmMRYJKwYBBAHaRw8BAQdAzXZnbofNVgtBglzMSqu0cVOgaoLEyAy6v6DX
mYSxwA+IywQfFgoAfQWCYvRmMQMLCQcJEDVGG/kcrtZ+RxQAAAAAAB4AIHNhbHRA
bm90YXRpb25zLnNlcXVvaWEtcGdwLm9yZ4F/S6gog/wBVOoLG3K8SaE5HOFe7EbF
Wgrxh1NKhCsCAxUKCAKbAQIeARYhBJzEZHwEQV2W7y9PzTVGG/kcrtZ+AAD9+AEA
l4BParFXikhZH4VXr1hRyfyWtV8hnwPcl9eU+igX/SgBAKYptO879hggMwu+9zJ+
x25eJW/EWW2i9S3mu5gMpysEtBA8YWNAYnVwc3Rhc2guaW8+iM4EExYKAIAFgmL0
ZjEDCwkHCRA1Rhv5HK7WfkcUAAAAAAAeACBzYWx0QG5vdGF0aW9ucy5zZXF1b2lh
LXBncC5vcmdbuNzNhBGXeid8J/vWVx3oQYgRa15JKnCMuu/ReEOHVwMVCggCmQEC
mwECHgEWIQScxGR8BEFdlu8vT801Rhv5HK7WfgAATK8BAJ7po0Ni9YNmvSDT4EsX
35MdvVYgtq22LJoDmLt7r+oRAQCKKWPsw13i6GPm4t5ozPqltdAR3xM7uEfGCzWJ
0VRfBLgzBGL0ZjEWCSsGAQQB2kcPAQEHQBF6vjySpi+RPabf1L9f3zP61m4OS2PP
HUE0QKUnIkDSiQF/BBgWCgExBYJi9GYxCRA1Rhv5HK7WfkcUAAAAAAAeACBzYWx0
QG5vdGF0aW9ucy5zZXF1b2lhLXBncC5vcme3EZvVUbn+0BUFL3iLpG6BVSixbxNQ
XfCT6kj5GDimRQKbAr6gBBkWCgBvBYJi9GYxCRAdZXgjz6ofGEcUAAAAAAAeACBz
YWx0QG5vdGF0aW9ucy5zZXF1b2lhLXBncC5vcmfk/iZ/MouT7uFwBvSNoD+CzhGR
ZLrUFY6Sh2nGnTPQyBYhBB9DxIpE4XsF0ukONx1leCPPqh8YAADeKwEAovED6zTC
29byTkr/VzFAha/Gtt/MnPJIC6gpCBSTpTABAMC/EGFMGiivTDdZXP1rqCpdFd8s
qF2mkYVgZyCXw/QMFiEEnMRkfARBXZbvL0/NNUYb+Ryu1n4AALNtAQDDWHOD0SEb
QgXyLk0Ho6yRvgCtSUiSHP3LH+iJpSVx5gEAk+SIGKThNW8BSaK1mzdTOu+Dsntn
Oxrp8vd+GE0RCwe4OARi9GYxEgorBgEEAZdVAQUBAQdA80nC4YzCtnH4hN41nQVE
QO0yNZHqycHgFKqxfodbElcDAQgJiMAEGBYKAHIFgmL0ZjEJEDVGG/kcrtZ+RxQA
AAAAAB4AIHNhbHRAbm90YXRpb25zLnNlcXVvaWEtcGdwLm9yZxJBdw1WDQVXRs8c
8DntJe+SkWMMOk4cM2VrTv7Tk6ssApsMFiEEnMRkfARBXZbvL0/NNUYb+Ryu1n4A
AK6YAP4sk5/dknfAxmnacYR5w6QqUhTRGvPZU6aRGtVk8eFY3AD+LjNttTyy5u9g
JC4NSoiQRLjFSOj8ypYwbSHMrzrRuA8=
=HZqW
-----END PGP PUBLIC KEY BLOCK-----
```

You can cross reference this PGP key at https://keys.openpgp.org/.

## SEE ALSO

bupstash(1)

==> bupstash-0.12.0.tar.gz: bupstash-0.12.0/doc/man/bupstash-authors.7.md <==
bupstash-authors(7)
===================

## SYNOPSIS

The bupstash authors, how to contact them, and their bupstash specific PGP public keys.

## Andrew Chambers

### About

Andrew is an an experienced programmer with a masters degree in computer systems engineering 
from the University of Auckland in New Zealand. He is the creator and primary author of bupstash
and bupstash.io.

### Contact

Email: ac@bupstash.io

### PGP Key

```
-----BEGIN PGP PUBLIC KEY BLOCK-----

mDMEYvRmMRYJKwYBBAHaRw8BAQdAzXZnbofNVgtBglzMSqu0cVOgaoLEyAy6v6DX
mYSxwA+IywQfFgoAfQWCYvRmMQMLCQcJEDVGG/kcrtZ+RxQAAAAAAB4AIHNhbHRA
bm90YXRpb25zLnNlcXVvaWEtcGdwLm9yZ4F/S6gog/wBVOoLG3K8SaE5HOFe7EbF
Wgrxh1NKhCsCAxUKCAKbAQIeARYhBJzEZHwEQV2W7y9PzTVGG/kcrtZ+AAD9+AEA
l4BParFXikhZH4VXr1hRyfyWtV8hnwPcl9eU+igX/SgBAKYptO879hggMwu+9zJ+
x25eJW/EWW2i9S3mu5gMpysEtBA8YWNAYnVwc3Rhc2guaW8+iM4EExYKAIAFgmL0
ZjEDCwkHCRA1Rhv5HK7WfkcUAAAAAAAeACBzYWx0QG5vdGF0aW9ucy5zZXF1b2lh
LXBncC5vcmdbuNzNhBGXeid8J/vWVx3oQYgRa15JKnCMuu/ReEOHVwMVCggCmQEC
mwECHgEWIQScxGR8BEFdlu8vT801Rhv5HK7WfgAATK8BAJ7po0Ni9YNmvSDT4EsX
35MdvVYgtq22LJoDmLt7r+oRAQCKKWPsw13i6GPm4t5ozPqltdAR3xM7uEfGCzWJ
0VRfBLgzBGL0ZjEWCSsGAQQB2kcPAQEHQBF6vjySpi+RPabf1L9f3zP61m4OS2PP
HUE0QKUnIkDSiQF/BBgWCgExBYJi9GYxCRA1Rhv5HK7WfkcUAAAAAAAeACBzYWx0
QG5vdGF0aW9ucy5zZXF1b2lhLXBncC5vcme3EZvVUbn+0BUFL3iLpG6BVSixbxNQ
XfCT6kj5GDimRQKbAr6gBBkWCgBvBYJi9GYxCRAdZXgjz6ofGEcUAAAAAAAeACBz
YWx0QG5vdGF0aW9ucy5zZXF1b2lhLXBncC5vcmfk/iZ/MouT7uFwBvSNoD+CzhGR
ZLrUFY6Sh2nGnTPQyBYhBB9DxIpE4XsF0ukONx1leCPPqh8YAADeKwEAovED6zTC
29byTkr/VzFAha/Gtt/MnPJIC6gpCBSTpTABAMC/EGFMGiivTDdZXP1rqCpdFd8s
qF2mkYVgZyCXw/QMFiEEnMRkfARBXZbvL0/NNUYb+Ryu1n4AALNtAQDDWHOD0SEb
QgXyLk0Ho6yRvgCtSUiSHP3LH+iJpSVx5gEAk+SIGKThNW8BSaK1mzdTOu+Dsntn
Oxrp8vd+GE0RCwe4OARi9GYxEgorBgEEAZdVAQUBAQdA80nC4YzCtnH4hN41nQVE
QO0yNZHqycHgFKqxfodbElcDAQgJiMAEGBYKAHIFgmL0ZjEJEDVGG/kcrtZ+RxQA
AAAAAB4AIHNhbHRAbm90YXRpb25zLnNlcXVvaWEtcGdwLm9yZxJBdw1WDQVXRs8c
8DntJe+SkWMMOk4cM2VrTv7Tk6ssApsMFiEEnMRkfARBXZbvL0/NNUYb+Ryu1n4A
AK6YAP4sk5/dknfAxmnacYR5w6QqUhTRGvPZU6aRGtVk8eFY3AD+LjNttTyy5u9g
JC4NSoiQRLjFSOj8ypYwbSHMrzrRuA8=
=HZqW
-----END PGP PUBLIC KEY BLOCK-----
```

You can cross reference this PGP key at https://keys.openpgp.org/.

## SEE ALSO

bupstash(1)
